@@ -1,24 +1,19 @@
 # copyright (C) 1997-1999 Jean-Luc Fontaine (mailto:jfontain@multimania.com)
 # this program is free software: please read the COPYRIGHT file enclosed in this package or use the Help Copyright menu
 
-set rcsId {$Id: arp.tcl,v 1.11 1998/12/26 16:38:31 jfontain Exp $}
+set rcsId {$Id: arp.tcl,v 1.15 1999/01/04 23:05:31 jfontain Exp $}
 
-package provide arp 1.1
 
+package provide arp 1.2
 package require network 1.2
 
-
 namespace eval arp {
 
-    if {[info exists ::env(MOODSSREMOTE)]} {                                                                    ;# remote monitoring
-        foreach {remote(user) remote(host)} [network::parseRemoteLocator $::env(MOODSSREMOTE)] {}
-    }
-
     array set data {
         updates 0
-        0,label IP 0,type dictionary 0,message {IP address}
+        0,label IP 0,type dictionary 0,message {IP address} 0,anchor left
         1,label hardware 1,type dictionary 1,message {hardware address}
-        2,label decoded 2,type dictionary 2,message {decoded hardware address}
+        2,label decoded 2,type dictionary 2,message {decoded hardware address} 2,anchor left
         3,label type 3,type ascii 3,message {hardware type}
         4,label flags 4,type ascii 4,message {entry flags (C: complete, M: permanent, P: published)}
         5,label interface 5,type ascii 5,message {networking interface}
@@ -31,31 +26,56 @@ Host addresses are looked up and converted to official names when possible.
 Hardware addresses are decoded, with a full name (from the /etc/ethers file if present, read once when the application is started), or with the vendor name for the first 3 bytes (from the vendor.txt file in the arp module sub directory).
 Note: you may update the vendor.txt file yourself by opening it from the http://pax.cavebear.com/CaveBear/Ethernet/ page and saving it as a text file under the vendor.txt name in the arp module sub directory (no editing needed).
 
-For remote monitoring (rsh facilities must be properly setup), set the environment variable MOODSSREMOTE to user@host or simply host for use with current user name.
+Module options:
+
+-n (--numeric): display numerical addresses instead of trying to determine symbolic host or network names.
+-r (--remote) [user@]host: remote monitoring using "user" as logname on remote host "host" (rsh facilities must be properly setup). If user is not specified, current user is used as logname on remote host.
+
+Examples:
+
+$ moodss arp --numeric
+$ moodss -- arp -n
+$ moodss arp -r jdoe@foo.bar.com
+$ moodss arp --remote foo.bar.com
         }
+        switches {-n 0 --numeric 0 -r 1 --remote 1}
     }
 
-    if {[info exists remote]} {
-        set data(pollTimes) {20 10 30 60 120 300 600}                                    ;# poll less often when remotely monitoring
-    } else {
-        set data(pollTimes) {10 5 20 30 60 120 300 600}
-    }
+    proc initialize {optionsName} {
+        upvar $optionsName options
+        variable lookup
+        variable remote
+        variable data
+        variable arpFile
+        variable etherName
 
-    catch {unset file}
-    if {[info exists remote]&&![catch "exec /usr/bin/rsh -l $remote(user) $remote(host) stat /etc/ethers"]} {   ;# access file first
-        set file [open "| /usr/bin/rsh -l $remote(user) $remote(host) cat /etc/ethers"]              ;# because opening always works
-    } else {
-        catch {set file [open /etc/ethers]}
-    }
-    if {[info exist file]} {                                                     ;# save ethernet address to name mapping if present
-        while {[gets $file line]>=0} {
-            if {[string match #* $line]} continue                                                                   ;# skip comments
-            if {[scan $line {%x:%x:%x:%x:%x:%x %s} byte(0) byte(1) byte(2) byte(3) byte(4) byte(5) name]==7} {
-                set address [format {%02X:%02X:%02X:%02X:%02X:%02X} $byte(0) $byte(1) $byte(2) $byte(3) $byte(4) $byte(5)]
-                set etherName($address) $name
+        set lookup [expr {![info exists options(-n)]&&![info exists options(--numeric)]}]            ;# host or network names lookup
+        if {![catch {set locator $options(--remote)}]||![catch {set locator $options(-r)}]} {                   ;# remote monitoring
+            set data(pollTimes) {20 10 30 60 120 300 600}                                ;# poll less often when remotely monitoring
+            foreach {remote(user) remote(host)} [network::parseRemoteLocator $locator] {}
+            if {[exec /usr/bin/rsh -nl $remote(user) $remote(host) {test -r /proc/net/arp; echo $?}]!=0} {
+                puts stderr "on remote host $remote(host) as user $remote(user), /proc/net/arp is not readable"
+                exit 1                                                                                        ;# detect errors early
             }
+            if {[exec /usr/bin/rsh -nl $remote(user) $remote(host) {test -r /etc/ethers; echo $?}]==0} {
+                # check file readability because opening always works
+                set ethernetFile [open "| /usr/bin/rsh -nl $remote(user) $remote(host) cat /etc/ethers"]
+            }
+        } else {
+            set data(pollTimes) {10 5 20 30 60 120 300 600}
+            catch {set ethernetFile [open /etc/ethers]}
+            set arpFile [open /proc/net/arp]                                          ;# keep local file open for better performance
+        }
+        if {[info exist ethernetFile]} {                                         ;# save ethernet address to name mapping if present
+            while {[gets $ethernetFile line]>=0} {
+                if {[string match #* $line]} continue                                                               ;# skip comments
+                if {[scan $line {%x:%x:%x:%x:%x:%x %s} byte(0) byte(1) byte(2) byte(3) byte(4) byte(5) name]==7} {
+                    set address [format {%02X:%02X:%02X:%02X:%02X:%02X} $byte(0) $byte(1) $byte(2) $byte(3) $byte(4) $byte(5)]
+                    set etherName($address) $name
+                }
+            }
+            close $ethernetFile
         }
-        close $file
     }
 
     set file [open [file join $packageDirectory vendor.txt]]                                ;# directory is set in pkgIndex.tcl file
@@ -74,32 +94,26 @@ For remote monitoring (rsh facilities must be properly setup), set the environme
         772 LOOPBACK 773 LOCALTLK 774 FDDI 775 BIF 776 SIT 777 IPDDP 778 IPGRE 779 PIMREG 780 HIPPI 781 ASH 782 ECONET 783 IRDA
     }
 
-
-    if {[info exists remote]&&[catch "exec /usr/bin/rsh -l $remote(user) $remote(host) stat /proc/net/arp" message]} {
-        puts stderr "on host $remote(host) as user $remote(user), file error: $message"                       ;# detect errors early
-        exit 1
-    } else {
-        set file [open /proc/net/arp]                                                 ;# keep local file open for better performance
-    }
     set nextIndex 0
 
     proc update {} {
         variable remote
-        variable file
+        variable arpFile
         variable index
         variable nextIndex
         variable data
         variable hardwareType
         variable etherName
         variable vendor
+        variable lookup
 
         if {[info exists remote]} {
-            set file [open "| /usr/bin/rsh -l $remote(user) $remote(host) cat /proc/net/arp"]
+            set arpFile [open "| /usr/bin/rsh -nl $remote(user) $remote(host) cat /proc/net/arp"]
         } else {
-            seek $file 0                                                                            ;# rewind before retrieving data
+            seek $arpFile 0                                                                         ;# rewind before retrieving data
         }
-        gets $file                                                                                               ;# skip header line
-        while {[gets $file line]>=0} {
+        gets $arpFile                                                                                            ;# skip header line
+        while {[gets $arpFile line]>=0} {
             scan $line {%u.%u.%u.%u 0x%x 0x%x %s %*s %s} ip(0) ip(1) ip(2) ip(3) type flags address interface
             if {[catch {set index($address)} row]} {
                 # new entry, use unique hardware address as index instead of IP address
@@ -121,7 +135,9 @@ For remote monitoring (rsh facilities must be properly setup), set the environme
                 }
             }
             set data($row,0) $ip(0).$ip(1).$ip(2).$ip(3)
-            catch {set data($row,0) [network::hostfromaddress $data($row,0)]}                                     ;# try name lookup
+            if {$lookup} {
+                catch {set data($row,0) [network::hostfromaddress $data($row,0)]}                                 ;# try name lookup
+            }
             set data($row,3) $hardwareType($type)
             set data($row,4) {}                                         ;# flags from the /usr/src/linux/include/linux/if_arp.h file
             if {$flags&2} {append data($row,4) C}                                                                 ;# completed entry
@@ -131,7 +147,7 @@ For remote monitoring (rsh facilities must be properly setup), set the environme
             set current($address) {}
         }
         if {[info exists remote]} {                                                 ;# closing is necessary since seek does not work
-            close $file
+            close $arpFile
         }
         foreach address [array names index] {                                                         ;# cleanup disappeared entries
             if {[info exists current($address)]} continue
