@@ -1,19 +1,14 @@
 # copyright (C) 1997-1999 Jean-Luc Fontaine (mailto:jfontain@multimania.com)
 # this program is free software: please read the COPYRIGHT file enclosed in this package or use the Help Copyright menu
 
-set rcsId {$Id: cpustats.tcl,v 1.13 1998/12/26 16:41:36 jfontain Exp $}
+set rcsId {$Id: cpustats.tcl,v 1.16 1999/01/04 23:07:03 jfontain Exp $}
 
-package provide cpustats 1.2
 
+package provide cpustats 1.3
 package require network 1.2
 
-
 namespace eval cpustats {
 
-    if {[info exists ::env(MOODSSREMOTE)]} {                                                                    ;# remote monitoring
-        foreach {remote(user) remote(host)} [network::parseRemoteLocator $::env(MOODSSREMOTE)] {}
-    }
-
     array set data {
         updates 0
         0,label {} 0,type ascii 0,message {}
@@ -26,40 +21,54 @@ namespace eval cpustats {
         helpText {
 This is a view of processor activity for the system as a whole.
 
-For remote monitoring (rsh facilities must be properly setup), set the environment variable MOODSSREMOTE to user@host or simply host for use with current user name.
+Module options:
+
+-r (--remote) [user@]host: remote monitoring using "user" as logname on remote host "host" (rsh facilities must be properly setup). If user is not specified, current user is used as logname on remote host.
+
+Examples:
+
+$ moodss ps -r jdoe@foo.bar.com
+$ moodss ps --remote foo.bar.com
+        }
+        switches {-r 1 --remote 1}
+    }
+
+    proc initialize {optionsName} {
+        upvar $optionsName options
+        variable remote
+        variable data
+        variable statisticsFile
+
+        set lookup [expr {![info exists options(-n)]&&![info exists options(--numeric)]}]            ;# host or network names lookup
+        if {![catch {set locator $options(--remote)}]||![catch {set locator $options(-r)}]} {                   ;# remote monitoring
+            set data(pollTimes) {20 10 30 60 120 300 600}                                ;# poll less often when remotely monitoring
+            foreach {remote(user) remote(host)} [network::parseRemoteLocator $locator] {}
+            if {[exec /usr/bin/rsh -nl $remote(user) $remote(host) {test -r /proc/stat; echo $?}]!=0} {
+                puts stderr "on remote host $remote(host) as user $remote(user), /proc/stat is not readable"
+                exit 1                                                                                        ;# detect errors early
+            }
+        } else {
+            set data(pollTimes) {10 5 20 30 60 120 300 600}
+            set statisticsFile [open /proc/stat]                                      ;# keep local file open for better performance
         }
     }
 
-    if {[info exists remote]} {
-        set data(pollTimes) {20 10 30 60 120 300}                                        ;# poll less often when remotely monitoring
-    } else {
-        set data(pollTimes) {10 5 20 30 60 120 300}
-    }
-
     array set data {0,0 percent}           ;# initialize single row index column with data unit so that viewer labels are meaningful
-
     array set last {user 0 nice 0 system 0 idle 0}                                                    ;# stored values for last poll
 
-    if {[info exists remote]&&[catch "exec /usr/bin/rsh -l $remote(user) $remote(host) stat /proc/stat" message]} {
-        puts stderr "on host $remote(host) as user $remote(user), file error: $message"                       ;# detect errors early
-        exit 1
-    } else {
-        set file [open /proc/stat]                                                    ;# keep local file open for better performance
-    }
-
     proc update {} {                                               ;# gather cpu statistics (based on the proc man page information)
         variable remote
-        variable file
+        variable statisticsFile
         variable last
         variable data
 
         if {[info exists remote]} {
-            set file [open "| /usr/bin/rsh -l $remote(user) $remote(host) cat /proc/stat"]
-            gets $file line
-            close $file                                                             ;# closing is necessary since seek does not work
+            set statisticsFile [open "| /usr/bin/rsh -nl $remote(user) $remote(host) cat /proc/stat"]
+            gets $statisticsFile line
+            close $statisticsFile                                                   ;# closing is necessary since seek does not work
         } else {
-            seek $file 0                                                                            ;# rewind before retrieving data
-            gets $file line
+            seek $statisticsFile 0                                                                  ;# rewind before retrieving data
+            gets $statisticsFile line
         }
         scan $line {cpu %d %d %d %d} user nice system idle                                              ;# in hundredths of a second
         foreach item {user nice system idle} {         ;# calculate statistics during the last poll period except for the first pass
