@@ -1,7 +1,7 @@
 # copyright (C) 1997-1999 Jean-Luc Fontaine (mailto:jfontain@multimania.com)
 # this program is free software: please read the COPYRIGHT file enclosed in this package or use the Help Copyright menu
 
-set rcsId {$Id: datatab.tcl,v 1.54 1998/12/26 10:43:44 jfontain Exp $}
+set rcsId {$Id: datatab.tcl,v 1.55 1999/01/02 14:03:45 jfontain Exp $}
 
 class dataTable {                       ;# module data view in the form of a table, that can be sorted using a column as a reference
 
@@ -308,7 +308,6 @@ class dataTable {                       ;# module data view in the form of a tab
     }
 
     proc createTitles {this} {
-        variable ${this}data
         upvar #0 $composite::($this,-data) data                                              ;# data must be visible at global level
 
         set path $dataTable::($this,tablePath)
@@ -379,6 +378,7 @@ class dataTable {                       ;# module data view in the form of a tab
         }
         createTitles $this
         updateSortingArrow $this $sortColumnIndex
+        setupColumnsAnchoring $this
         setTrace $this 1
     }
 
@@ -407,4 +407,25 @@ class dataTable {                       ;# module data view in the form of a tab
         }
         trace $command $composite::($this,-data)(updates) w "dataTable::update $this"                          ;# track data updates
     }
+
+    proc setupColumnsAnchoring {this} {                                              ;# handle eventual data anchor column attribute
+        upvar #0 $composite::($this,-data) data
+
+        set column -1
+        set path $dataTable::($this,tablePath)
+        foreach dataColumn $dataTable::($this,dataColumns) {
+            incr column
+            if {[catch {set anchor $data($dataColumn,anchor)}]} continue      ;# no anchor for this column, default (center) is used
+            if {![regexp {^center|left|right$} $anchor]} {
+                error "bad anchor value \"$anchor\": must be center, left or right"
+            }
+            if {[string compare $anchor center]==0} continue                  ;# nothing to do as center is column anchoring default
+            if {![$path tag exists $anchor]} {        ;# create anchor tag as needed and use valid anchor values (see above) as name
+                array set convert {left w right e}
+                $path tag configure $anchor -anchor $convert($anchor)
+            }
+            $path tag col $anchor $column
+        }
+    }
+
 }
