@@ -1,7 +1,7 @@
 # copyright (C) 1997-1999 Jean-Luc Fontaine (mailto:jfontain@multimania.com)
 # this program is free software: please read the COPYRIGHT file enclosed in this package or use the Help Copyright menu
 
-set rcsId {$Id: help.tcl,v 1.27 1998/12/26 10:43:44 jfontain Exp $}
+set rcsId {$Id: help.tcl,v 1.28 1999/01/10 21:24:43 jfontain Exp $}
 
 namespace eval help {
 
@@ -132,7 +132,11 @@ proc aboutDialogBox {} {
 
 proc modulesHelpDialogBox {args} {                                                                     ;# arguments are module names
     foreach module $args {
-        append text "$module module (version [package provide $module]):\n"
+        append text "$module module (version [package provide $module])"
+        if {[string length $modules::($module,arguments)]>0} {
+            append text ", (invoked with arguments: $modules::($module,arguments))"
+        }
+        append text ":\n"
         if {[catch {append text [set ${module}::data(helpText)]}]} {
              append text "\nno help available\n"
         }
