@@ -39,6 +39,14 @@ set htmlHelpContents {
 
 <LI>
 <A HREF="#commandline">5.2. Command line</A></LI>
+
+<UL>
+<LI>
+<A HREF="#mainarguments">5.2.1. Main arguments</A></LI>
+
+<LI>
+<A HREF="#modulearguments">5.2.2. Module arguments</A></LI>
+</UL>
 </UL>
 </UL>
 </BODY>
@@ -106,6 +114,8 @@ and which can also embed live data cells in text form.
 <P>Versions 5.3 and up support viewer type mutation through viewer icon
 drag'n'drop, and viewer quick destruction through trash icon drag'n'drop
 operation. A new menu for empty viewer creation was also added.
+<P>Versions 6.0 and up support command line arguments per module, data
+table column anchoring in module configuration and automatic module discovery.
 <P>Since module data access is entirely customizable (through C code, Tcl,
 HTTP, ...) and since several modules can be loaded at once, applications
 for moodss become limitless. For example, comparing a remote database server
@@ -132,10 +142,10 @@ menu for more information.
 <A NAME="required"></A>3. Required software</H3>
 If you are using a Linux Redhat system (5.1 or above), then use the moodss
 rpm file (available (starting with 4.4) at <A HREF="http://www.multimania.com/jfontain/">http://www.multimania.com/jfontain/</A>)
-for installation. It includes all the required software and libraries (except
-Tcl/Tk 8.x, of course). Unless you want to work on the moodss source code,
-you can skip the rest of this section.
-<P>For the current version (5.8), the following packages must be installed
+for installation. It requires the tcl, tk, blt and tktable rpms (see INSTALL
+file for more information). Unless you want to work on the moodss source
+code, you can skip the rest of this section.
+<P>For the current version (6.0), the following packages must be installed
 before attempting to install moodss (make sure to check the INSTALL file
 for the latest information):
 <UL>
@@ -143,7 +153,7 @@ for the latest information):
 Tcl/Tk version 8.0 or above (at <A HREF="http://sunscript.sun.com/">http://sunscript.sun.com/</A>)</LI>
 
 <LI>
-tkTable version 2.3 or above (at <A HREF="http://oprs.mchh.siemens.de/tcl/capp/tkTable/">http://oprs.mchh.siemens.de/tcl/capp/tkTable/</A>)<B>*</B></LI>
+tkTable version 2.2 or above (at <A HREF="http://oprs.mchh.siemens.de/tcl/capp/tkTable/">http://oprs.mchh.siemens.de/tcl/capp/tkTable/</A>)<B>*</B></LI>
 
 <LI>
 the BLT library version 2.4 (at <A HREF="ftp://ftp.tcltk.com/pub/blt/">ftp://ftp.tcltk.com/pub/blt/</A>)<B>*</B></LI>
@@ -501,19 +511,22 @@ Save</I> menu is used. The <I>File Save As</I> menu may be used at any
 time to change the file name.
 <H4>
 <A NAME="commandline"></A>5.2. Command line</H4>
+
+<H5>
+<A NAME="mainarguments"></A>5.2.1. Main arguments</H5>
 Launching moodss is very simple: just pass one or more data module names
 as parameters, as in:
-<PRE>$ wish moodss random</PRE>
+<PRE>&nbsp;&nbsp;&nbsp; $ wish moodss random</PRE>
 or, for 2 modules at once:
-<PRE>$ wish moodss ps cpustats</PRE>
+<PRE>&nbsp;&nbsp;&nbsp; $ wish moodss ps cpustats</PRE>
 You may not specify the same module more than once in the command line.
 <P>You may eventually specify a poll time in seconds using:
-<PRE>$ wish moodss -p 25 random</PRE>
+<PRE>&nbsp;&nbsp;&nbsp; $ wish moodss -p 25 random</PRE>
 Note that when all the specified modules are asynchronous, the poll time
 option specifies the preferred interval for graph viewers.
 <P>Once saved through the File Save menus (for example in save.moo) , the
 configuration can be retrieved using:
-<PRE>$ wish moodss -f save.moo</PRE>
+<PRE>&nbsp;&nbsp;&nbsp; $ wish moodss -f save.moo</PRE>
 which would result in the same modules being loaded, the same viewers displayed
 at the same positions and sizes, the same poll time being used, as well
 at the same application window size. New modules data displays can be added
@@ -522,13 +535,13 @@ command line after the -f (--file) switch / value pair.
 <P>Command line options include:
 <UL>
 <LI>
-<B>-f</B> (or <B>--file</B>): specifies a configuration file name</LI>
+<B>-f</B> (or <B>--file</B>): specify a configuration file name</LI>
 
 <LI>
-<B>-h</B> (or <B>--help</B>): displays some help text and exits</LI>
+<B>-h</B> (or <B>--help</B>): display some help text and exit</LI>
 
 <LI>
-<B>-p</B> (or <B>--poll-time</B>): specifies a poll time in seconds</LI>
+<B>-p</B> (or <B>--poll-time</B>): specify a poll time in seconds</LI>
 
 <LI>
 <B>-r</B> (or <B>--read-only</B>): disable viewer creation, editing, ...</LI>
@@ -538,8 +551,31 @@ command line after the -f (--file) switch / value pair.
 and moving</LI>
 
 <LI>
-<B>--version</B>: outputs version information and exits</LI>
+<B>--show-modules</B>: discover valid moodss modules, show their directory
+location(s) and exit</LI>
+
+<LI>
+<B>--version</B>: output version information and exit</LI>
 </UL>
+Moodss command line options must appear before any module name appears
+on the command line, so as not to interfere with the module options.
+<H5>
+<A NAME="modulearguments"></A>5.2.2. Module arguments</H5>
+Module themselves can take options (if programmed to do so, see <A HREF="#initialization">module
+initialization</A>), through command line arguments placed right after
+the module name and before the next module name, if any.
+<P>For example, the following command:
+<PRE>&nbsp;&nbsp;&nbsp; $ moodss -p 15 random --asynchronous arp --remote jdoe@foo.bar --numeric route --numeric</PRE>
+causes the <I>random</I> module to update asynchronously, the <I>arp</I>
+module to collect data from the <I>foo.bar</I> host under the <I>jdoe</I>
+login name and not attempt to lookup symbolic names for hosts, with the
+last module <I>route</I> doing the same.
+<P>Note the setting the application poll time to 15 seconds does not interfere
+with the module options.
+<P>The moodss core checks the validity of module options according to the
+information provided by the module programmer. Any invalid option / value
+combination for the module is detected, reported on the standard error
+channel before the application exits.
 </BODY>
 </HTML>
 }
