@@ -1,23 +1,19 @@
 # copyright (C) 1997-1999 Jean-Luc Fontaine (mailto:jfontain@multimania.com)
 # this program is free software: please read the COPYRIGHT file enclosed in this package or use the Help Copyright menu
 
-set rcsId {$Id: route.tcl,v 1.7 1998/12/26 16:43:01 jfontain Exp $}
+set rcsId {$Id: route.tcl,v 1.11 1999/01/04 23:18:26 jfontain Exp $}
 
-package provide route 1.1
 
+package provide route 1.2
 package require network 1.2
 
 namespace eval route {
 
-    if {[info exists ::env(MOODSSREMOTE)]} {                                                                    ;# remote monitoring
-        foreach {remote(user) remote(host)} [network::parseRemoteLocator $::env(MOODSSREMOTE)] {}
-    }
-
     array set data {
         updates 0
         0,label interface 0,type ascii 0,message {networking interface}
-        1,label destination 1,type dictionary 1,message {destination network or host, or default}
-        2,label gateway 2,type dictionary 2,message {gateway address, if any}
+        1,label destination 1,type dictionary 1,message {destination network or host, or default} 1,anchor left
+        2,label gateway 2,type dictionary 2,message {gateway address, if any} 2,anchor left
         3,label flags 3,type ascii 3,message {D: dynamic, G: gateway, H: host, M: modified, R: reinstate, U: up, !: reject}
         4,label mask 4,type dictionary 4,message {network mask (empty for default route)}
         5,label references 5,type integer 5,message {number of references to the route}
@@ -28,39 +24,59 @@ namespace eval route {
 This is a view of network routes for the system (tested on IPv4 only).
 Networks and hosts addresses are looked up and converted to official names when possible.
 
-For remote monitoring (rsh facilities must be properly setup), set the environment variable MOODSSREMOTE to user@host or simply host for use with current user name.
+Module options:
+
+-n (--numeric): display numerical addresses instead of trying to determine symbolic host or network names.
+-r (--remote) [user@]host: remote monitoring using "user" as logname on remote host "host" (rsh facilities must be properly setup). If user is not specified, current user is used as logname on remote host.
+
+Examples:
+
+$ moodss route --numeric
+$ moodss -- route -n
+$ moodss route -r jdoe@foo.bar.com
+$ moodss route --remote foo.bar.com
         }
+        switches {-n 0 --numeric 0 -r 1 --remote 1}
     }
 
-    if {[info exists remote]} {
-        set data(pollTimes) {20 10 30 60 120 300 600}                                    ;# poll less often when remotely monitoring
-    } else {
-        set data(pollTimes) {10 5 20 30 60 120 300 600}
-    }
+    proc initialize {optionsName} {
+        upvar $optionsName options
+        variable lookup
+        variable remote
+        variable data
+        variable routeFile
 
-    if {[info exists remote]&&[catch "exec /usr/bin/rsh -l $remote(user) $remote(host) stat /proc/net/route" message]} {
-        puts stderr "on host $remote(host) as user $remote(user), file error: $message"                       ;# detect errors early
-        exit 1
-    } else {
-        set file [open /proc/net/route]                                               ;# keep local file open for better performance
+        set lookup [expr {![info exists options(-n)]&&![info exists options(--numeric)]}]            ;# host or network names lookup
+        if {![catch {set locator $options(--remote)}]||![catch {set locator $options(-r)}]} {                   ;# remote monitoring
+            set data(pollTimes) {20 10 30 60 120 300 600}                                ;# poll less often when remotely monitoring
+            foreach {remote(user) remote(host)} [network::parseRemoteLocator $locator] {}
+            if {[exec /usr/bin/rsh -nl $remote(user) $remote(host) {test -r /proc/net/route; echo $?}]!=0} {
+                puts stderr "on remote host $remote(host) as user $remote(user), /proc/net/route is not readable"
+                exit 1                                                                                        ;# detect errors early
+            }
+        } else {
+            set data(pollTimes) {10 5 20 30 60 120 300 600}
+            set routeFile [open /proc/net/route]                                      ;# keep local file open for better performance
+        }
     }
 
     set nextIndex 0
 
     proc update {} {
         variable remote
-        variable file
+        variable routeFile
         variable index
         variable nextIndex
         variable data
+        variable lookup
 
         if {[info exists remote]} {
-            set file [open "| /usr/bin/rsh -l $remote(user) $remote(host) cat /proc/net/route"]
+            set routeFile [open "| /usr/bin/rsh -nl $remote(user) $remote(host) cat /proc/net/route"]
         } else {
-            seek $file 0                                                                            ;# rewind before retrieving data
+            seek $routeFile 0                                                                       ;# rewind before retrieving data
         }
-        gets $file                                                                                               ;# skip header line
-        while {[gets $file line]>=0} {
+        gets $routeFile                                                                                          ;# skip header line
+        while {[gets $routeFile line]>=0} {
             scan $line {%s %2x%2x%2x%2x %2x%2x%2x%2x %x %u %u %u %2x%2x%2x%2x}\
                 interface destination(3) destination(2) destination(1) destination(0)\
                 gateway(3) gateway(2) gateway(1) gateway(0) flags references use metric mask(3) mask(2) mask(1) mask(0)
@@ -72,14 +88,19 @@ For remote monitoring (rsh facilities must be properly setup), set the environme
             set data($row,0) $interface
             if {[string compare $address 0.0.0.0]==0} {                                                             ;# default route
                 set data($row,1) default
-            } elseif {[catch {set data($row,1) [network::networkfromaddress $address]}]} {                        ;# try name lookup
+            } else {
                 set data($row,1) $address
+                if {$lookup} {
+                    catch {set data($row,1) [network::networkfromaddress $address]}                               ;# try name lookup
+                }
             }
             set data($row,2) $gateway(0).$gateway(1).$gateway(2).$gateway(3)
             if {[string compare $data($row,2) 0.0.0.0]==0} {
                 set data($row,2) {}                                                                                    ;# no gateway
             } else {
-                catch {set data($row,2) [network::hostfromaddress $data($row,2)]}                                 ;# try name lookup
+                if {$lookup} {
+                    catch {set data($row,2) [network::hostfromaddress $data($row,2)]}                             ;# try name lookup
+                }
             }
             set data($row,3) [network::routeletterflags $flags]
             set data($row,4) $mask(0).$mask(1).$mask(2).$mask(3)
@@ -92,7 +113,7 @@ For remote monitoring (rsh facilities must be properly setup), set the environme
             set current($address) {}
         }
         if {[info exists remote]} {                                                 ;# closing is necessary since seek does not work
-            close $file
+            close $routeFile
         }
         foreach address [array names index] {                                                         ;# cleanup disappeared entries
             if {[info exists current($address)]} continue
